searchData={"content_type":"text/markdown","items":[{"doc":"Telemetry handler for creating OpenTelemetry Spans from Ecto query events. Any\nrelation preloads, which are executed in parallel in separate tasks, will be\nlinked to the span of the process that initiated the call. For example:\n\n    Tracer.with_span \"parent span\" do\n      Repo.all(Query.from(User, preload: [:posts, :comments]))\n    end\n\nthis will create a span called \"parent span\" with three child spans for each\nquery: users, posts, and comments.\n\n> ##","ref":"OpentelemetryEcto.html","title":"OpentelemetryEcto","type":"module"},{"doc":">\n> Due to limitations with how Ecto emits its telemetry, nested preloads are not\n> represented as nested spans within a trace.","ref":"OpentelemetryEcto.html#module-note-neutral","title":"Note {: .neutral} - OpentelemetryEcto","type":"module"},{"doc":"Attaches the OpentelemetryEcto handler to your repo events. This should be called\nfrom your application behaviour on startup.\n\nExample:\n\n    OpentelemetryEcto.setup([:blog, :repo])\n\nYou may also supply the following options in the second argument:\n\n  * `:time_unit` - a time unit used to convert the values of query phase\n    timings, defaults to `:microsecond`. See `System.convert_time_unit/3`\n  * `:span_prefix` - the first part of the span name, as a `String.t`,\n    defaults to the concatenation of the event name with periods, e.g.\n    `\"blog.repo.query\"`. This will always be followed with a colon and the\n    source (the table name for SQL adapters).\n  * `:additional_attributes` - additional attributes to include in the span. If there\n    are conflits with default provided attributes, the ones provided with\n    this config will have precedence.\n  * `:db_statement` - :disabled (default) | :enabled | fun\n    Whether or not to include db statements.\n    Optionally provide a function that takes a query string and returns a\n    sanitized version of it. This is useful for removing sensitive information from the\n    query string. Unless this option is `:enabled` or a function,\n    query statements will not be recorded on spans.","ref":"OpentelemetryEcto.html#setup/2","title":"OpentelemetryEcto.setup/2","type":"function"},{"doc":"# OpentelemetryEcto\n\nTelemetry handler that creates Opentelemetry spans from Ecto query events. Because\nEcto emits telemetry events only after queries have finished, OpentelemetryEcto\nestimates the start time of the span by subtracting the reported total duration\nfrom the current timestamp.\n\nAfter installing, setup the handler in your application behaviour before your\ntop-level supervisor starts.\n\n```elixir\nOpentelemetryEcto.setup([:blog, :repo])\n```\n\nSee the documentation for `OpentelemetryEcto.setup/2` for additional options that\nmay be supplied.","ref":"readme.html","title":"OpentelemetryEcto","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `opentelemetry_ecto` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:opentelemetry_ecto, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - OpentelemetryEcto","type":"extras"},{"doc":"| OpentelemetryEcto Version | Otel Version | Notes |\n| :------------------------ | :----------- | :---- |\n|                           |              |       |\n| v0.1.0                    | <= v.0.5.0   |       |\n| v1.0.0-rc.1               | v1.0.0-rc.1  |       |\n| v1.0.0-rc.2               | v1.0.0-rc.2  |       |\n| v1.0.0-rc.3               | v1.0.0-rc.3  |       |\n| v1.0.0-rc.4               | v1.0.0-rc.4  |       |\n| v1.0                      | v1.0         |       |\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at [https://hexdocs.pm/opentelemetry_ecto](https://hexdocs.pm/opentelemetry_ecto).","ref":"readme.html#compatibility-matrix","title":"Compatibility Matrix - OpentelemetryEcto","type":"extras"}]}